#include "platform.h"
#include "mainwindow.h"
#include <QDebug>
#include <qapplication.h>

/// The update interval (milliseconds) for the platform movement.
#define TICK_SPEED 15
/// The width of the platform.
#define PLATFORM_WIDTH 100
/// The height of the platform.
#define PLATFORM_HEIGHT 20
/// The distance of the platform from the bottom of the window.
#define PLATFORM_MARGIN_BOTTOM 80
/// The speed at which the platform moves.
#define SPEED 10.0

Platform::Platform(MainWindow* parent) : m_parent{parent} {
    QRect rct = parent->rect();

    m_x = rand() % (rct.width() - PLATFORM_WIDTH);
    m_y = rct.height() - (PLATFORM_HEIGHT + PLATFORM_MARGIN_BOTTOM);

    start(TICK_SPEED);
}

void Platform::draw(QPainter& painter) {
    painter.drawRect(rect());
}

void Platform::timerEvent(QTimerEvent*) {
    int direction = 0;
    if (m_parent->leftArrowPressed && !m_parent->rightArrowPressed)
        direction = -1;
    else if (m_parent->rightArrowPressed && !m_parent->leftArrowPressed)
        direction = 1;

    // Don't move on horizontal collision
    QRect rct = m_parent->rect();
    if (m_x > rct.width() - PLATFORM_WIDTH && direction == 1)
        direction = 0;
    if (m_x < 0 && direction == -1)
        direction = 0;

    m_x += direction * SPEED;

    m_parent->update();
}

QRect Platform::rect() const {
    return QRect(m_x, m_y, PLATFORM_WIDTH, PLATFORM_HEIGHT);
}
