#ifndef PLATFORM_H
#define PLATFORM_H

#include <QPainter>
#include <QTimer>
#include <QWidget>

// Forward declaration, avoiding circular import of mainwindow.h
// (this probably isn't the best way to handle this, but I wasn't
// sure how else to do it.)
class MainWindow;

class Platform : public QTimer {
    Q_OBJECT

  public:
    /**
    * @brief Constructs a Platform object.
    *
    * Initializes the platform at a random horizontal position within the window
    * and sets its vertical position near the bottom.
    *
    * @param parent Pointer to the main window.
    */
    Platform(MainWindow* parent);

    /**
    * @brief Draws the platform on the screen.
    *
    * @param painter Reference to the QPainter used for rendering.
    */
    void draw(QPainter& painter);

    /**
    * @brief Returns the bounding rectangle of the platform.
    *
    * @return QRect representing the platform's current position and size.
    */
    QRect rect() const;

  protected:
    /**
    * @brief Handles the platform's movement and updates its position.
    *
    * The platform moves left or right depending on the arrow key states.
    * Ensures the platform does not move beyond window boundaries.
    *
    * @param event Pointer to the timer event (not used explicitly).
    */
    virtual void timerEvent(QTimerEvent*) override;

  private:
    MainWindow* m_parent;
    double m_x;
    double m_y;
};

#endif // PLATFORM_H
